@@ -20,9 +20,6 @@ datasummary_extract <- function(tab,
     }
   }
 
-  # output object
-  out <- list()
-
   # NA to empty cells
   clean_na <- function(x) {
     out <- trimws(x)
@@ -33,7 +30,7 @@ datasummary_extract <- function(tab,
 
   # fill-in spanning column labels horizontally
   carry_forward <- function(x, empty = '') {
-    out <- trimws(x)
+    x <- trimws(x)
     if (length(x) > 1) {
       for (i in 2:length(x)) {
         if (is.na(x[i])) {
