@@ -15,14 +15,14 @@
 #' @param type of variables to summarize: "numeric" or "categorical" (character)
 #'
 #' @examples
-#' 
+#'
 #' \dontrun{
 #' dat <- mtcars
 #' dat$vs <- as.logical(dat$vs)
 #' dat$cyl <- as.factor(dat$vs)
 #' datasummary_skim(dat)
 #' datasummary_skim(dat, "categorical")
-#' 
+#'
 #' # You can use `datasummary` to produce a similar table in different formats.
 #' # Note that the `Histogram` function relies on unicode characters. These
 #' # characters will only display correctly in some operating systems, under some
@@ -53,20 +53,20 @@ datasummary_skim <- function(data,
   data <- as.data.frame(data)
 
   if (type == "numeric") {
-    out <- datasummary_skim_numeric(data, output=output, fmt=fmt,
-                                    histogram=histogram, title=title,
-                                    notes=notes, align=align, ...)
-  } 
+    out <- datasummary_skim_numeric(data, output = output, fmt = fmt,
+                                    histogram = histogram, title = title,
+                                    notes = notes, align = align, ...)
+  }
 
   if (type == "categorical") {
-    out <- datasummary_skim_categorical(data, output=output, fmt=fmt,
-                                        title=title, notes=notes, align=align,
+    out <- datasummary_skim_categorical(data, output = output, fmt = fmt,
+                                        title = title, notes = notes, align = align,
                                         ...)
-  } 
+  }
 
   if (type == "dataset") {
-    out <- datasummary_skim_dataset(data, output=output, title=title,
-                                    notes=notes, align=align, ...)
+    out <- datasummary_skim_dataset(data, output = output, title = title,
+                                    notes = notes, align = align, ...)
   }
 
   return(out)
@@ -89,8 +89,8 @@ datasummary_skim_dataset <- function(
     tryCatch(length(unique(stats::na.omit(x))) == 2, error = function(e) FALSE, silent = TRUE)
   }
   out <- c(
-    Rows = rounding(nrow(data), fmt=0),
-    Columns = rounding(ncol(data), fmt=0),
+    Rows = rounding(nrow(data), fmt = 0),
+    Columns = rounding(ncol(data), fmt = 0),
     # `# Binary` = rounding(sum(sapply(data, is.binary)), 0),
     `# Character` = rounding(sum(sapply(data, is.character)), 0),
     `# Factor` = rounding(sum(sapply(data, is.factor)), 0),
@@ -99,7 +99,7 @@ datasummary_skim_dataset <- function(
     `% Missing` = rounding(mean(is.na(data) * 100), 0)
   )
   out <- data.frame(names(out), out)
-  out <- out[out[[2]] != "0" | out[[1]] == "% Missing",]
+  out <- out[out[[2]] != "0" | out[[1]] == "% Missing", ]
   row.names(out) <- NULL
   colnames(out) <- c(" ", "  ")
 
@@ -130,7 +130,7 @@ datasummary_skim_numeric <- function(
   ...) {
 
   # output format
-  output_info <- parse_output_arg(output)
+  output_info <- sanitize_output(output)
 
   # draw histogram?
   if (histogram) {
@@ -171,15 +171,20 @@ datasummary_skim_numeric <- function(
 
   }
 
-  # subset of numeric variables 
+  # subset of numeric variables
   idx <- sapply(data, is.numeric)
   if (!any(idx)) stop('data contains no numeric variable.')
-  dat_new <- data[, idx, drop=FALSE] 
+  dat_new <- data[, idx, drop = FALSE]
 
   # subset of non-NA variables
   idx <- sapply(dat_new, function(x) !all(is.na(x)))
   if (!any(idx)) stop('all numeric variables are completely missing.')
-  dat_new <- dat_new[, idx, drop=FALSE]
+  dat_new <- dat_new[, idx, drop = FALSE]
+
+  # convert to numeric (tables does not play well with haven_labelled)
+  for (i in seq_along(dat_new)) {
+    dat_new[[i]] <- as.numeric(dat_new[[i]])
+  }
 
   # pad colnames in case one is named Min, Max, Mean, or other function name
   # colnames(dat_new) <- paste0(colnames(dat_new), " ")
@@ -189,8 +194,8 @@ datasummary_skim_numeric <- function(
 
     histogram_col <- function(x) ""
 
-    f <- All(dat_new, numeric=TRUE, factor=FALSE) ~
-         Heading("Unique (#)") * NUnique + 
+    f <- All(dat_new, numeric = TRUE, factor = FALSE) ~
+         Heading("Unique (#)") * NUnique +
          Heading("Missing (%)") * PercentMissing +
          (Mean + SD + Min + Median + Max) * Arguments(fmt = fmt) +
          Heading("") * histogram_col
@@ -200,8 +205,8 @@ datasummary_skim_numeric <- function(
     # know the exact subset of variables kept by tabular, in the exact
     # order, to print the right histograms.
 
-    idx <- datasummary(f, data=dat_new, output="data.frame")[[1]]
-    histogram_list <- as.list(dat_new[, idx, drop=FALSE])
+    idx <- datasummary(f, data = dat_new, output = "data.frame")[[1]]
+    histogram_list <- as.list(dat_new[, idx, drop = FALSE])
     histogram_list <- lapply(histogram_list, stats::na.omit)
 
     # too large
@@ -210,7 +215,7 @@ datasummary_skim_numeric <- function(
     }
 
     # don't use output=filepath.html when post-processing
-    if (!is.null(output_info$output_file)) { 
+    if (!is.null(output_info$output_file)) {
       output <- "kableExtra"
     }
 
@@ -220,17 +225,17 @@ datasummary_skim_numeric <- function(
         output = output,
         title = title,
         align = align,
-        notes = notes) 
+        notes = notes)
     out <- kableExtra::column_spec(out,
-        column=9, 
-        image=kableExtra::spec_hist(histogram_list, 
-                                    col="black",
-                                    same_lim=FALSE)
+        column = 9,
+        image = kableExtra::spec_hist(histogram_list,
+                                      col = "black",
+                                      same_lim = FALSE)
       )
 
     # don't use output=filepath.html when post-processing
     if (!is.null(output_info$output_file)) {
-      kableExtra::save_kable(out, file=output_info$output_file)
+      kableExtra::save_kable(out, file = output_info$output_file)
       return(invisible(out))
     }
 
@@ -238,7 +243,7 @@ datasummary_skim_numeric <- function(
   } else {
 
     f <- All(dat_new, numeric = TRUE, factor = FALSE) ~
-         Heading("Unique (#)") * NUnique + 
+         Heading("Unique (#)") * NUnique +
          Heading("Missing (%)") * PercentMissing +
          (Mean + SD + Min + Median + Max) * Arguments(fmt = fmt)
 
@@ -247,7 +252,7 @@ datasummary_skim_numeric <- function(
         output = output,
         title = title,
         align = align,
-        notes = notes) 
+        notes = notes)
 
   }
 
@@ -278,8 +283,8 @@ datasummary_skim_categorical <- function(
 
   for (n in colnames(dat_new)) {
 
-    if (is.logical(dat_new[[n]]) | 
-        is.character(dat_new[[n]]) | 
+    if (is.logical(dat_new[[n]]) |
+        is.character(dat_new[[n]]) |
         is.factor(dat_new[[n]])) {
 
       # convert to factor
@@ -330,8 +335,8 @@ datasummary_skim_categorical <- function(
     warning(sprintf("These variables were omitted because they are entirely missing: %s.", paste(drop_entirely_na, collapse=", ")))
   }
 
-  pctformat = function(x) rounding(x, fmt)
-  f <- All(dat_new, numeric=FALSE, factor=TRUE, logical=TRUE, character=TRUE) ~
+  pctformat <- function(x) rounding(x, fmt)
+  f <- All(dat_new, numeric = FALSE, factor = TRUE, logical = TRUE, character = TRUE) ~
        (N = 1) * Format(digits=0) + (`%` = Percent()) * Format(pctformat())
 
   out <- datasummary(
@@ -340,8 +345,8 @@ datasummary_skim_categorical <- function(
     output = output,
     title = title,
     align = align,
-    notes = notes) 
+    notes = notes)
 
   return(out)
 
-} 
+}
