@@ -1,15 +1,40 @@
-library(modelsummary)
-
+skip_if_not_installed("estimatr")
 
 random_string <- function() {
   paste(sample(letters, 30, replace=TRUE), collapse="")
 }
 
-context('datasummary_balance')
+test_that("errors and warnings", {
+
+  # missing RHS variable
+  tmp <- data.frame(ID = as.character(1:100),
+    Y = rnorm(100),
+    Z_comp = sample(0:20, 100, replace = TRUE))
+  expect_error(datasummary_balance(~k, tmp),
+               regexp = "must be in data")
+
+  # too many factor levels in condition variable
+  expect_error(datasummary_balance(~Z_comp, tmp),
+               regexp = "wide to be readable")
+
+  # warn about drops
+  tmp <- data.frame(
+    Y = rnorm(100),
+    K = NA_real_,
+    Z_comp = sample(0:1, 100, replace = TRUE))
+  expect_warning(datasummary_balance(~Z_comp, tmp),
+                 regexp = "entirely missing")
+
+  tmp <- data.frame(
+    Y = rnorm(100),
+    K = as.character(1:100),
+    Z_comp = sample(0:1, 100, replace = TRUE))
+  expect_warning(datasummary_balance(~Z_comp, tmp),
+                 regexp = "include more than 50")
+})
 
 
 test_that("column percentages sum to 100 within factors", {
-  testthat::skip_if_not_installed("estimatr")
   dat <- mtcars[, c("vs", "cyl", "gear")]
   dat$cyl <- factor(dat$cyl)
   dat$gear <- factor(dat$gear)
@@ -20,24 +45,24 @@ test_that("column percentages sum to 100 within factors", {
   expect_true(all(tapply(as.numeric(tab[[6]]), idx, f)))
 })
 
+
 test_that("palmer penguins was once broken with kableExtra", {
-  testthat::skip_if_not_installed("estimatr")
   penguins <- "https://vincentarelbundock.github.io/Rdatasets/csv/palmerpenguins/penguins.csv"
   penguins <- read.csv(penguins)
   raw <- datasummary_balance(~sex, penguins, output="html")
   expect_known_output(cat(raw), "known_output/datasummary_balance_penguins.html", update=FALSE)
 })
 
+
 test_that('variable name with spaces', {
-  testthat::skip_if_not_installed("estimatr")
   tmp <- mtcars
   colnames(tmp)[1] <- "testing spaces"
   tab <- expect_error(datasummary_balance(~vs, data=tmp, output="dataframe"), NA)
   expect_equal(dim(tab), c(10, 7))
 })
 
+
 test_that('add column', {
-  testthat::skip_if_not_installed("estimatr")
   tmp <- mtcars
   tmp$gear <- as.factor(tmp$gear)
   tmp$vs <- as.logical(tmp$vs)
@@ -49,8 +74,8 @@ test_that('add column', {
   expect_equal(dim(tab), c(13, 9))
 })
 
+
 test_that('only numeric', {
-  testthat::skip_if_not_installed("estimatr")
   tab <- datasummary_balance(~vs, mtcars, output = 'dataframe')
   truth <- c(" ", "0 Mean", "0 Std. Dev.", "1 Mean",
     "1 Std. Dev.", "Diff. in Means", "Std. Error")
@@ -59,6 +84,7 @@ test_that('only numeric', {
   expect_equal(colnames(tab), truth)
 })
 
+
 test_that('only factors', {
   tmp <- mtcars
   tmp$cyl <- factor(tmp$cyl)
@@ -72,8 +98,8 @@ test_that('only factors', {
   expect_equal(colnames(tab), truth)
 })
 
+
 test_that('both factors and numerics', {
-  testthat::skip_if_not_installed("estimatr")
   tmp <- mtcars
   tmp$cyl <- factor(tmp$cyl)
   tmp$gear <- factor(tmp$gear)
@@ -86,21 +112,20 @@ test_that('both factors and numerics', {
   expect_equal(colnames(tab), truth)
 })
 
+
 test_that('more than two conditions', {
-  testthat::skip_if_not_installed("estimatr")
   tmp <- mtcars
   tmp$cyl <- factor(tmp$cyl)
   tmp$vs <- as.logical(tmp$vs)
   tab <- datasummary_balance(~gear, tmp, output = 'dataframe', dinm = FALSE)
   expect_s3_class(tab, 'data.frame')
   expect_equal(dim(tab), c(14, 8))
-
   tab <- expect_warning(datasummary_balance(~gear, tmp, output = 'dataframe', dinm = TRUE))
   expect_equal(dim(tab), c(14, 8))
 })
 
+
 test_that('single numeric', {
-  testthat::skip_if_not_installed("estimatr")
   tmp <- mtcars[, c('am', 'mpg')]
   tab <- datasummary_balance(~am, data = tmp, output = 'dataframe')
   expect_s3_class(tab, 'data.frame')
@@ -108,8 +133,8 @@ test_that('single numeric', {
   expect_equal(tab[[1]], 'mpg')
 })
 
+
 test_that('single factor', {
-  testthat::skip_if_not_installed("estimatr")
   tmp <- mtcars[, c('am', 'gear')]
   tmp$gear <- factor(tmp$gear)
   tab <- datasummary_balance(~am, data = tmp, output = 'dataframe')
@@ -118,6 +143,7 @@ test_that('single factor', {
   expect_equal(tab[[2]][1], '3')
 })
 
+
 test_that('dinm=FALSE', {
   tab <- datasummary_balance(~vs, mtcars, dinm = FALSE, output = 'dataframe')
   expect_s3_class(tab, 'data.frame')
@@ -125,18 +151,22 @@ test_that('dinm=FALSE', {
   expect_equal(tab[[1]][1], 'mpg')
 })
 
+
 test_that('dinm_statistic = "p.value"', {
-  testthat::skip_if_not_installed("estimatr")
   tab <- datasummary_balance(~vs, mtcars, dinm_statistic = 'p.value',
     output = 'dataframe')
   expect_s3_class(tab, 'data.frame')
   expect_equal(dim(tab), c(10, 7))
   expect_equal(tab[[1]][1], 'mpg')
   expect_equal(colnames(tab)[ncol(tab)], 'p')
+
+  # sanity checks prevent other than p.value or std.error
+  expect_error(
+    datasummary_balance(~vs, mtcars, dinm_statistic = 'bad', output = 'dataframe'))
 })
 
+
 test_that('fmt', {
-  testthat::skip_if_not_installed("estimatr")
   tmp <- mtcars[, c('am', 'mpg', 'gear')]
   tmp$gear <- factor(tmp$gear)
   truth <- c("17.15", "N", "15", "4", "0")
@@ -144,17 +174,19 @@ test_that('fmt', {
   expect_equal(tab[[3]], truth)
 })
 
-test_that('too many factor levels', {
-  testthat::skip_if_not_installed("estimatr")
+
+
+
+test_that('too many levels in row variable', {
   set.seed(10)
   dat <- data.frame(ID = as.character(1:100),
     Y = rnorm(100),
-    Z_comp = sample(0:20, 100, replace = TRUE))
-  expect_error(datasummary_balance(~Z_comp, dat))
+    Z_comp = sample(0:1, 100, replace = TRUE))
+  expect_warning(datasummary_balance(~Z_comp, dat))
 })
 
+
 test_that('estimatr: clusters, blocks, weights', {
-  testthat::skip_if_not_installed("estimatr")
 
   set.seed(286342)
   # clusters
